@@ -9,4 +9,12 @@ def get_files_in_path_dict(pathdict):
                 retval.add(file)
         else:
             retval.add(pathdict[tag])
-    return retval
\ No newline at end of file
+    return retval
+
+
+class classproperty(object):
+    def __init__(self, getter):
+        self.getter = getter
+
+    def __get__(self, instance, owner):
+        return self.getter(owner)
\ No newline at end of file
